#
# Copyright (c) M-Logic, Inc.
#
# $Id$
package MT::Plugin::DataAPIDisabler;

use strict;
use warnings;
use MT;
use MT::Plugin;
use base qw( MT::Plugin );

our $PLUGIN_NAME = 'DataAPI Disabler';
our $VERSION = '1.0';

my $plugin = new MT::Plugin::DataAPIDisabler({
    id => 'DataAPIDisabler',
    key => 'DataAPIDisabler',
    name => $PLUGIN_NAME,
    version => $VERSION,
    description => '<__trans phrase="This plugin manage permission of Data API access for blogs.">',
    doc_link => 'http://labs.m-logic.jp/plugins/dataapi-disabler/docs/' . $VERSION . '/dataapi-disabler.html',
    author_name => 'M-Logic, Inc.',
    author_link => 'http://labs.m-logic.jp/',
    l10n_class => 'DataAPIDisabler::L10N',
    schema_version => '0.12',
    registry => {
        applications => {
            cms => {
                callbacks => {
                    'data_api_pre_load_filtered_list.blog' => \&filter_list_blog,
                    'data_api_save_permission_filter'      => \&filter_perm,
                    'data_api_delete_permission_filter'    => \&filter_perm,
                    'data_api_view_permission_filter'      => \&filter_perm,
                    'data_api_list_permission_filter'      => \&filter_perm,
                },
            },
        },
        object_types => {
            'blog' => {
                'is_api_disabled' => 'integer not null',
            },
        },
        list_properties => {
            'blog' => {
                is_api_disabled => {
                    auto => 1,
                    display => 'none',
                },
            },
        },
        web_services => {
            'DataAPIDisabler' => {
                config_template => \&web_services_tmpl,
                save_config => \&web_services_save,
            },
        },
    },

});

package DataAPIDisabler::L10N;
1;

package DataAPIDisabler::L10N::ja;
use strict;
use base 'DataAPIDisabler::L10N';
use vars qw( %Lexicon );
use utf8;
%Lexicon = (
'This plugin manage permission of Data API access for blogs.' => 'このプラグインはData APIのアクセス許可を設定します。',
'This option is ignored when calling DataAPI with using system administrator\'s AccessToken.' => 'システム管理者のトークンを使用してData APIにアクセスする場合にはこの設定は無視されます。',
'Data API Settings' => 'Data API 設定',
'Accept DataAPI' => 'Data API 許可',
'Accept DataAPI call' => 'Data APIを許可する',
);
1;

package MT::Plugin::DataAPIDisabler;

# required MT6.0
if (MT->version_number >= 6.0) {
    MT->add_plugin($plugin);
}

sub instance { $plugin; }

sub web_services_tmpl {
    my $app    = MT->instance;
    my $blog   = $app->blog or return;

    require MT::Template;
    require MT::Template::Context;
    my $tmpl = MT::Template->new;
    $tmpl->text(<<'HTML');
    <__trans_section component="dataapidisabler">
    <h2><__trans phrase="Data API Settings"></h2>
    <mtapp:settinggroup id="dataapi-settings">
      <mtapp:setting
         id="dataapi_block"
         label="<__trans phrase="Accept DataAPI">"
         hint="<__trans phrase="This option is ignored when calling DataAPI with using system administrator's AccessToken.">"
         show_hint="1">
        <ul>
          <li><input type="checkbox" name="dataapi_is_enabled" id="dataapi_is_enabled" value="1"<mt:unless name="is_api_disabled"> checked="checked"</mt:unless> class="cb" /> <label for="dataapi_is_enabled"><__trans phrase="Accept DataAPI call"></label></li>
        </ul>
      </mtapp:setting>
    </mtapp:settinggroup>
    </__trans_section>
HTML
    my $ctx = MT::Template::Context->new;
    $ctx->stash( 'blog',    $blog );
    $ctx->stash( 'blog_id', $blog->id );
    $ctx->var( 'is_api_disabled', $blog->is_api_disabled );
    return $tmpl->build($ctx);
}

sub web_services_save {
    my ( $cb, $app, $blog ) = @_;

    my $blog = $app->blog or return;
    $blog->is_api_disabled($app->param( 'dataapi_is_enabled' ) ? 0 : 1);
    $blog->save;
    return 1;
}

# Data API support
sub filter_list_blog {
    my ($cb, $app, $filter, $opts, $cols) = @_;
    $filter->append_item(
        {   type => 'pack',
            args => {
                op     => 'and',
                items  => [
                    {
                        type   => 'is_api_disabled',
                        args   => {
                            option => 'not_equal',
                            value  => 1,
                        },
                    },
                ],
            },
        }
    );
    1;
}

sub filter_perm {
    my ($cb, $app) = @_;

    my $q       = $app->param;
    my $blog_id = $q->param('blog_id') or return 1;
    my $blog    = MT->model('blog')->load( $blog_id ) or return 1;
    return $blog->is_api_disabled ? 0 : 1;
}

1;
